@@ -144,7 +144,7 @@ cat("\n")
   data[data == missing.val] = missing_est
   log_like = log_likelihood_normal2pl_cpp(as.matrix(data), ndim, as.matrix(beta.estimate), as.matrix(alpha.estimate), as.matrix(theta.estimate), gamma.estimate, z.est, w.est, sigma.estimate, missing.val)
   p = 2 * nitem + nsample + 1 + 1 + ndim * nitem + ndim * nsample + 1
-  bic = -2 * log_like[[1]] + p * log(nsample * nsample)
+  bic = -2 * log_like[[1]] + p * log(nitem * nsample)
 
   result <- list(data = data,
               missing.val = missing.val,
